@@ -1,5 +1,5 @@
-#This file is part of Tryton.  The COPYRIGHT file at the top level of
-#this repository contains the full copyright notices and license terms.
+# This file is part of Tryton.  The COPYRIGHT file at the top level of
+# this repository contains the full copyright notices and license terms.
 
 import operator
 import types
@@ -112,6 +112,18 @@ def inverse_leaf(domain):
         return map(inverse_leaf, domain)
 
 
+def filter_leaf(domain, field, model):
+    if domain in ('AND', 'OR'):
+        return domain
+    elif is_leaf(domain):
+        if domain[0].startswith(field) and len(domain) > 3:
+            if domain[3] != model:
+                return ('id', '=', None)
+        return domain
+    else:
+        return [filter_leaf(d, field, model) for d in domain]
+
+
 def eval_domain(domain, context, boolop=operator.and_):
     "compute domain boolean value according to the context"
     if is_leaf(domain):
@@ -143,7 +155,7 @@ def localize_domain(domain, field_name=None):
         if isinstance(domain[2], basestring):
             locale_name = 'rec_name'
         return [locale_part(domain[0], field_name, locale_name)] \
-            + list(domain[1:])
+            + list(domain[1:3]) + list(domain[4:])
     else:
         return [localize_domain(part, field_name) for part in domain]
 
@@ -193,6 +205,17 @@ def concat(*domains, **kwargs):
     return simplify(merge(result))
 
 
+def unique_value(domain):
+    "Return if unique, the field and the value"
+    if (isinstance(domain, list)
+            and len(domain) == 1
+            and '.' not in domain[0][0]
+            and domain[0][1] == '='):
+        return True, domain[0][1], domain[0][2]
+    else:
+        return False, None, None
+
+
 def parse(domain):
     if is_leaf(domain):
         return domain
@@ -295,7 +318,7 @@ class Or(And):
                 field = self.base(field)
                 if (field in context
                         and (eval_leaf(part, context, operator.or_)
-                                or constrained_leaf(part, operator.or_))):
+                            or constrained_leaf(part, operator.or_))):
                     return True
                 elif (field in context
                         and not eval_leaf(part, context, operator.or_)):
@@ -481,6 +504,17 @@ def test_concat():
         'OR', [['a', '=', 1]], [['b', '=', 2]]]
 
 
+def test_unique_value():
+    domain = [['a', '=', 1]]
+    assert unique_value(domain) == (True, '=', 1)
+    domain = [['a', '!=', 1]]
+    assert unique_value(domain)[0] is False
+    domain = [['a', '=', 1], ['a', '=', 2]]
+    assert unique_value(domain)[0] is False
+    domain = [['a.b', '=', 1]]
+    assert unique_value(domain)[0] is False
+
+
 def test_evaldomain():
     domain = [['x', '>', 5]]
     assert eval_domain(domain, {'x': 6})
@@ -573,6 +607,12 @@ def test_localize():
     domain = [['x', 'child_of', [1], 'y']]
     assert localize_domain(domain, 'x') == [['y', 'child_of', [1]]]
 
+    domain = [['x.id', '=', 1, 'y']]
+    assert localize_domain(domain, 'x') == [['id', '=', 1]]
+
+    domain = [['a.b.c', '=', 1, 'y', 'z']]
+    assert localize_domain(domain, 'x') == [['b.c', '=', 1, 'z']]
+
 if __name__ == '__main__':
     test_simple_inversion()
     test_and_inversion()
