@@ -1,23 +1,22 @@
-#This file is part of Tryton.  The COPYRIGHT file at the top level of
-#this repository contains the full copyright notices and license terms.
+# This file is part of Tryton.  The COPYRIGHT file at the top level of
+# this repository contains the full copyright notices and license terms.
 import operator
-from functools import cmp_to_key
 import gtk
 import gettext
 from collections import defaultdict
 
 from . import View
 from tryton.common.focus import (get_invisible_ancestor, find_focused_child,
-    next_focus_widget, find_focusable_child, tab_compare)
+    next_focus_widget, find_focusable_child, find_first_focus_widget)
 from tryton.common import Tooltips, node_attributes, ICONFACTORY
 from tryton.common.button import Button
 from tryton.config import CONFIG
-from .form_gtk.calendar import Calendar, DateTime, Time
+from .form_gtk.calendar import Date, Time, DateTime
 from .form_gtk.float import Float
 from .form_gtk.integer import Integer
 from .form_gtk.selection import Selection
 from .form_gtk.char import Char, Password
-from .form_gtk.float_time import FloatTime
+from .form_gtk.timedelta import TimeDelta
 from .form_gtk.checkbox import CheckBox
 from .form_gtk.reference import Reference
 from .form_gtk.binary import Binary
@@ -206,13 +205,6 @@ class ViewForm(View):
         attributes.setdefault('colspan', 4)
         notebook = Notebook(attrs=attributes)
         notebook.set_scrollable(True)
-        positions = {
-            'top': gtk.POS_TOP,
-            'left': gtk.POS_LEFT,
-            'right': gtk.POS_RIGHT,
-            'bottom': gtk.POS_BOTTOM,
-            }
-        notebook.set_tab_pos(positions[CONFIG['client.form_tab']])
         notebook.set_border_width(3)
 
         # Force to display the first time it switches on a page
@@ -232,21 +224,7 @@ class ViewForm(View):
         self.parse(node, notebook)
 
     def _parse_page(self, node, notebook, attributes):
-        if CONFIG['client.form_tab'] == 'left':
-            angle = 90
-            tab_box = gtk.VBox(spacing=3)
-            image_pos, image_rotate = ('end',
-                gtk.gdk.PIXBUF_ROTATE_COUNTERCLOCKWISE)
-        elif CONFIG['client.form_tab'] == 'right':
-            angle = -90
-            tab_box = gtk.VBox(spacing=3)
-            image_pos, image_rotate = ('start',
-                gtk.gdk.PIXBUF_ROTATE_CLOCKWISE)
-        else:
-            angle = 0
-            tab_box = gtk.HBox(spacing=3)
-            image_pos, image_rotate = ('start',
-                gtk.gdk.PIXBUF_ROTATE_NONE)
+        tab_box = gtk.HBox(spacing=3)
         if 'name' in attributes:
             field = self.screen.group.fields[attributes['name']]
             if attributes['name'] == self.screen.exclude_field:
@@ -257,7 +235,6 @@ class ViewForm(View):
         if '_' not in attributes['string']:
             attributes['string'] = '_' + attributes['string']
         label = gtk.Label(attributes['string'])
-        label.set_angle(angle)
         label.set_use_underline(True)
         tab_box.pack_start(label)
 
@@ -265,13 +242,9 @@ class ViewForm(View):
             ICONFACTORY.register_icon(attributes['icon'])
             pixbuf = tab_box.render_icon(attributes['icon'],
                 gtk.ICON_SIZE_SMALL_TOOLBAR)
-            pixbuf = pixbuf.rotate_simple(image_rotate)
             icon = gtk.Image()
             icon.set_from_pixbuf(pixbuf)
-            if image_pos == 'end':
-                tab_box.pack_end(icon)
-            else:
-                tab_box.pack_start(icon)
+            tab_box.pack_start(icon)
         tab_box.show_all()
 
         viewport = gtk.Viewport()
@@ -365,7 +338,7 @@ class ViewForm(View):
         pack(container.table, resize=True, shrink=True)
 
     WIDGETS = {
-        'date': Calendar,
+        'date': Date,
         'datetime': DateTime,
         'time': Time,
         'float': Float,
@@ -375,7 +348,7 @@ class ViewForm(View):
         'selection': Selection,
         'char': Char,
         'password': Password,
-        'float_time': FloatTime,
+        'timedelta': TimeDelta,
         'boolean': CheckBox,
         'reference': Reference,
         'binary': Binary,
@@ -484,7 +457,7 @@ class ViewForm(View):
                 for notebook in self.notebooks:
                     notebook.set_current_page(0)
             if self.attributes.get('cursor') in self.widgets:
-                focus_widget = find_focused_child(self.widgets[
+                focus_widget = find_focusable_child(self.widgets[
                         self.attributes['cursor']][0].widget)
             else:
                 child = find_focusable_child(self._viewport)
@@ -499,11 +472,12 @@ class ViewForm(View):
                     if not field:
                         continue
                     if not field.get_state_attrs(record).get('valid', True):
-                        invalid_widgets.append(
-                            find_focusable_child(widget.widget))
-            invalid_widgets.sort(key=cmp_to_key(tab_compare))
+                        invalid_widget = find_focusable_child(widget.widget)
+                        if invalid_widget:
+                            invalid_widgets.append(invalid_widget)
             if invalid_widgets:
-                focus_widget = invalid_widgets[0]
+                focus_widget = find_first_focus_widget(
+                    self._viewport, invalid_widgets)
         if focus_widget:
             for notebook in self.notebooks:
                 for i in range(notebook.get_n_pages()):
